@@ -87,13 +87,13 @@ class DbObject(object):
         return get_objects(cls, filter)
 
     @classmethod
-    """
-    This method can be called to create an object
-
-    :param class: The class which calls this method
-    :return: The freshly created object
-    """
     def create(cls, *args, **kwargs):
+        """
+        This method can be called to create an object
+
+        :param class: The class which calls this method
+        :return: The freshly created object
+        """
         return cls.adaptor.create(cls, cls.tablename, cls.fields.keys(), kwargs)
 
     def save(self, *args, **kwargs):
@@ -114,13 +114,13 @@ class DbObject(object):
         return self.adaptor.delete(self.tablename, self)
 
     @classmethod
-    """
-    Function which can be used to select items from the database by pure SQL
-
-    :param query: A pure SQL select query
-    :return: An object of the calling class
-    """
     def pure(cls, *args):
+        """
+        Function which can be used to select items from the database by pure SQL
+
+        :param query: A pure SQL select query
+        :return: An object of the calling class
+        """
         return [cls(*item) for item in cls.adaptor.get_by_sql(args[0])]
 
     @classmethod
@@ -462,4 +462,90 @@ class SQLiteAdaptor(Adaptor):
 
         query = """CREATE TABLE IF NOT EXISTS %s (%s)""" % (cls.tablename, fields[:-2])
         cls.raw(query)
-        return True
\ No newline at end of file
+        return True
+
+
+class MyDbAdaptor(Adaptor):
+    """
+    Pet project
+    """
+
+    def __init__(self, database):
+        self.database = database
+
+    def get_connection(self):
+        import db_driver
+        con = db_driver.connect(self.database)
+        return con
+
+    def get_key_value(cls, key, value, *args):
+        tablename = args[0]
+        fields = args[1]
+        list = ['int', 'date', 'bool']
+        if fields[key] in list:
+            value = "'%s'" % value
+
+        if fields[key] == 'char':
+            value = "'%s'" % value
+        return (key, value)
+
+    def get_by_sql(self, query, *args):
+        con = self.get_connection()
+        return con.execute(query)
+
+    def get_by_filter(self, filter, *args):
+        tablename = args[0]
+        fieldnames = args[1]
+        query = "SELECT %s FROM %s WHERE %s" % (', '.join(fieldnames),
+                                                tablename,
+                                                filter)
+        return self.get_by_sql(query, *args)
+
+    def update(self, tablename, fieldnames, *args):
+        _object = args[0]
+        settings = ""
+        for fieldname in fieldnames:
+            settings += ", " + fieldname + "=%s"
+        settings = settings[2:]
+
+        query = "UPDATE %s SET %s WHERE id=%%s" % (tablename, settings)
+
+        values = []
+        for fieldname in fieldnames:
+            values.append(getattr(_object, fieldname))
+        values.append(_object.id)
+
+        con = self.get_connection()
+        con.execute(query % tuple(values))
+
+    def create(self, cls, tablename, fieldnames, *args, **kwargs):
+        empty_fields = set(fieldnames)
+        field_values = {}
+
+        for key, value in args[0].iteritems():
+            if key not in fieldnames:
+                raise InvalidFieldName
+            else:
+                empty_fields -= set([key])
+                field_values[key] = value
+
+        for key in empty_fields:
+            field_values[key] = None
+
+        query = "INSERT INTO %s (%s) VALUES (%s)" % (
+                                       tablename,
+                                       ', '.join(field_values.keys()),
+                                       ', '.join(['%s'] * len(fieldnames)))
+
+        values = []
+        for value in field_values.values():
+            values.append(value)
+
+        con = self.get_connection()
+        return cls.get(id=con.execute(query % tuple(values)))
+
+    def delete(self, tablename, *args):
+        _object = args[0]
+        query = "DELETE FROM %s WHERE id=%s" % (tablename, _object.id)
+        con = self.get_connection()
+        con.execute(query)
